<!--
 Copyright European Organization for Nuclear Research (CERN)

 Licensed under the Apache License, Version 2.0 (the "License");
 You may not use this file except in compliance with the License.
 You may obtain a copy of the License at
 http://www.apache.org/licenses/LICENSE-2.0

 Authors:
 - Mario Lassnig, <mario.lassnig@cern.ch>, 2014
 - Thomas Beermann, <thomas.beermann@cern.ch>, 2014-2015
-->

$var title: Data Identifier
$var script: <script src="/static/did.js"></script><link rel="stylesheet" href="//cdn.datatables.net/1.10.2/css/jquery.dataTables.min.css"><script src="//cdn.datatables.net/1.10.2/js/jquery.dataTables.min.js"></script>

<div id="result" class="row" data-equalizer>

  <div id="metadata" class="columns panel">
    <h4>DID Metadata</h4>
    <div id="loading">Loading, please wait...</div>
    <table id="t_metadata" style="word-wrap: break-word;">
    </table>
  </div>

</div>

<div id="result_contents" class="row">
</div>

<div id="result_rules" class="row">
</div>

<div id="result_dataset_replicas" class="row">
</div>

<div id="result_file_replicas" class="row">
</div>

<div id="problem_details" style="margin: 2em;"></div>
