
# This file is automatically generated by setup.py, So don't edit it. :)
VERSION_INFO = {
    'final': True,
    'version': '1.9.5',
    'branch_nick': '(detached',
    'revision_id': '7be2268136224ca6dfdd287694815bcc2a7313fb',
    'revno': 4614
}
